pub struct StatisticalTimeRange {
pub type_of_statistical_processing: u8,
pub type_of_time_increment: u8,
pub time_range_unit: u8,
pub time_range_length: u32,
pub time_increment_unit: u8,
pub time_increment: u32,
}Expand description
Statistical processing descriptor from GRIB2 Product Definition templates with one or more time range specifications.
Fields
type_of_statistical_processing: u8type_of_time_increment: u8time_range_unit: u8time_range_length: u32time_increment_unit: u8time_increment: u32Trait Implementations
Sourceimpl Clone for StatisticalTimeRange
impl Clone for StatisticalTimeRange
Sourcefn clone(&self) -> StatisticalTimeRange
fn clone(&self) -> StatisticalTimeRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatisticalTimeRange
impl Debug for StatisticalTimeRange
impl Eq for StatisticalTimeRange
Sourceimpl PartialEq for StatisticalTimeRange
impl PartialEq for StatisticalTimeRange
Sourcefn eq(&self, other: &StatisticalTimeRange) -> bool
fn eq(&self, other: &StatisticalTimeRange) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StatisticalTimeRange